farmfe_core0.7.0

Module plugin

Module Items

  • Modules
  • Structs
  • Enums
  • Constants
  • Traits

In crate farmfe_core

farmfe_core

Module plugin

Modules

  • constants
  • plugin_driver

Structs

  • ArchivedPluginAnalyzeDepsHookResultEntry
    An archived PluginAnalyzeDepsHookResultEntry
  • ArchivedPluginGenerateResourcesHookResult
    An archived PluginGenerateResourcesHookResult
  • EmptyPluginHookParam
  • EmptyPluginHookResult
  • PluginAnalyzeDepsHookParam
  • PluginAnalyzeDepsHookResultEntry
  • PluginAnalyzeDepsHookResultEntryResolver
    The resolver for an archived PluginAnalyzeDepsHookResultEntry
  • PluginDriverRenderResourcePotHookResult
  • PluginFinalizeModuleHookParam
  • PluginFinalizeResourcesHookParams
  • PluginGenerateResourcesHookResult
  • PluginGenerateResourcesHookResultResolver
    The resolver for an archived PluginGenerateResourcesHookResult
  • PluginHandleEntryResourceHookParams
  • PluginHookContext
    Plugin hook call context, designed for first type hook, used to provide info when call plugins from another plugin
  • PluginLoadHookParam
  • PluginLoadHookResult
  • PluginModuleGraphUpdatedHookParams
  • PluginParseHookParam
  • PluginProcessModuleHookParam
  • PluginRenderResourcePotHookParam
  • PluginRenderResourcePotHookResult
  • PluginResolveHookParam
    Parameter of the resolve hook
  • PluginResolveHookResult
  • PluginTransformHookParam
  • PluginTransformHookResult
  • PluginUpdateModulesHookParams
  • UpdateResult
    The output after the updating process
  • WatchDiffResult

Enums

  • ArchivedResolveKind
    An archived ResolveKind
  • ResolveKind
  • ResolveKindResolver
    The resolver for an archived ResolveKind
  • UpdateType

Constants

  • DEFAULT_PRIORITY

Traits

  • Plugin